@@ -186,6 +186,26 @@ save_state (GnomeClient *client)
   return TRUE;
 }
 
+/* Check for the existence of a particular variation and fall back to
+   a default if it isn't found. */
+static void check_game_file_name (void)
+{
+  gchar *fullpath;
+  gchar *partialpath;
+
+  partialpath = g_strconcat (GAMESDIR, game_file, NULL);
+  fullpath = gnome_program_locate_file (NULL,
+					GNOME_FILE_DOMAIN_APP_DATADIR,
+					partialpath,
+					FALSE, NULL);
+  if (!g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
+    game_file = DEFAULT_VARIATION;
+  }
+
+  g_free (fullpath);
+  g_free (partialpath);
+}
+
 void new_game (gchar* file, guint *seedp)
 {
   SCM size;
@@ -201,14 +221,15 @@ void new_game (gchar* file, guint *seedp)
 
   if (file && strcmp (file, game_file)) {
     game_file = file;
+    check_game_file_name ();
     
     /* Although this line slows down game switching by a noticeable amount, we
      * add it here in order to make sure all the original functions are
      * "clean". */
     eval_installed_file ("sol.scm");
-    eval_installed_file (file);
+    eval_installed_file (game_file);
 
-    game_name = game_file_to_name (file);
+    game_name = game_file_to_name (game_file);
     update_statistics_display ();
     help_update_game_name (game_name);
     install_options_menu (game_name);
