@@ -101,7 +101,7 @@ load_bubble_graphic (gchar *fname, GdkPixbuf **pixbuf)
 {
 
   if (!g_file_test (fname, G_FILE_TEST_EXISTS)) {
-    printf (_("Could not find \'%s\' image file for GNOME Robots\n"), fname);
+    printf (_("Could not find \'%s\' pixmap file\n"), fname);
     return FALSE;
   }
 
@@ -223,13 +223,18 @@ load_game_graphics (void)
     image = gdk_pixbuf_new_from_file (buffer, NULL);
     g_free (buffer);
 
-    /*game_graphic[num_graphics]->bgcolor.pixel = gdk_image_get_pixel (tmpimage, 0, 0);*/
-
-    game_graphic[num_graphics]->pixbuf = image;
-
-    num_graphics++;
+    if (image == NULL) {
+      g_free (game_graphic[num_graphics]->name);
+      g_free (game_graphic[num_graphics]);
+    } else {
+      game_graphic[num_graphics]->pixbuf = image;
+      num_graphics++;
+    }
   }
 
+  if (num_graphics == 0)
+    return FALSE;
+
   g_dir_close (dir);
 
   current_graphics = 0;
@@ -394,7 +399,7 @@ set_background_color (GdkColor color)
     colormap = gtk_widget_get_colormap (game_area);
     gdk_colormap_alloc_color (colormap, &color, FALSE, TRUE);
 
-    gdk_window_set_background (game_area->window, &color);
+    gtk_widget_modify_bg (game_area, GTK_STATE_NORMAL, &color);
   }
 }
 
@@ -427,7 +432,6 @@ set_background_color_from_name (gchar *name)
 void
 draw_tile_pixmap (gint tileno, gint pno, gint x, gint y, GtkWidget *area)
 {
-
   gdk_window_clear_area (area->window, x, y, TILE_WIDTH, TILE_HEIGHT);
 
   if ((tileno < 0) || (tileno >= SCENARIO_PIXMAP_WIDTH)) {
