@@ -64,12 +64,12 @@ extern int posy;
 extern int nr_of_colors;
 
 extern bool random_block_colors;
-extern bool do_preview;
 
-class	Field;
+class Field;
 class Preview;
-class	BlockOps;
+class BlockOps;
 class ScoreFrame;
+class HighScores;
 
 class Tetris
 {
@@ -95,6 +95,7 @@ private:
 	Preview *preview;
 	BlockOps *ops;
 	ScoreFrame *scoreFrame;
+	HighScores *high_scores;
 
 	GConfClient *gconf_client;
 	
@@ -116,13 +117,15 @@ private:
 			     gint x, gint y, GtkSelectionData *data, 
 			     guint info, guint time, Tetris *t);
 	static int timeoutHandler(void *d);
-	static int gameQuit(GtkWidget *widget, void *d);
-	static int gameNew(GtkWidget *widget, void *d);
-	static int gamePause(GtkWidget *widget, void *d);
-	static int gameEnd(GtkWidget *widget, void *d);
-	static int gameAbout(GtkWidget *widget, void *d);
-	static int gameTopTen(GtkWidget *widget, void *d);
-	static int gameProperties(GtkWidget *widget, void *d);
+	static int gameQuit(GtkAction *action, void *d);
+	static int gameNew(GtkAction *action, void *d);
+	static int focusOut(GtkWidget *widget, GdkEvent *e, Tetris *t);
+	static int gamePause(GtkAction *action, void *d);
+	static int gameEnd(GtkAction *action, void *d);
+	static int gameHelp(GtkAction *action, void *d);
+	static int gameAbout(GtkAction *action, void *d);
+	static int gameTopTen(GtkAction *action, void *d);
+	static int gameProperties(GtkAction *action, void *d);
 	static void setupdialogDestroy(GtkWidget *widget, void *d);
 	static void setupdialogResponse(GtkWidget *dialog, gint response_id, void *d);
 	static void setSound (GtkWidget *widget, gpointer data);
@@ -167,7 +170,9 @@ private:
 	GtkWidget *random_block_colors_toggle;
 	GtkWidget *rotate_counter_clock_wise_toggle;
 	GtkWidget *sound_toggle;
-	
+
+	Preview *theme_preview;
+
 	int moveLeft;
 	int moveRight;
 	int moveDown;
@@ -175,18 +180,18 @@ private:
 	int moveRotate;
 	int movePause;
 	
-	GnomeUIInfo *gameMenuPtr; 
-	GnomeUIInfo *gameSettingsPtr; 
+	GtkAction *new_game_action;
+	GtkAction *pause_action;
+	GtkAction *resume_action;
+	GtkAction *scores_action;
+	GtkAction *end_game_action;
+	GtkAction *preferences_action;
 
 	void manageFallen();
-	void showScores(gchar *title, guint pos);
 
 	bool fastFall;
 	int fastFallPoints;
         bool dropBlock;
-
-        GnomeCanvasItem * pauseMessage;
-        GnomeCanvasItem * gameoverMessage;
 };
 
 #endif // __tetris_h__
