@@ -6,7 +6,9 @@
  *
  */
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <string.h>
 
 #include "same-gnome.h"
 
